package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`%0`!````)"(`$`````!``````````+BQ````
M`````@```$``.``(`$``&@`9``8````%````0`````````!````0`````$``
M`!``````P`$```````#``0````````@``````````P````0``````@``````
M```"`!````````(`$``````1`````````!$``````````0`````````!````
M!0``````````````````$``````````0`````)2I````````E*D`````````
M``$```````$````&````J*T```````"HK0$0`````*BM`1``````Z`(`````
M``!(%0```````````0```````@````8```#`K0```````,"M`1``````P*T!
M$`````!``@```````$`"````````"``````````$````!````!0"````````
M%`(`$``````4`@`0`````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```"HK0```````*BM`1``````J*T!$`````!8`@``````
M`%@"`````````0`````````O;&EB-C0O;&0V-"YS;RXR``````0````0````
M`0```$=.50```````@````8````@````!````!0````#````1TY5``:R<U*6
MBG58B\(C+J&E=F4U2AT@$0```$\````$````"````"`0$``%0`2$*@(``("&
M`*""*0``"2`$"8B@&$6Z!`((`````$\```!3````6````%D```!?````8```
M`&$```!C````9`````````!F````9P```&@```!I``````````````!NQ=\?
MZM/O#L[>1RUK?YI\+L6;MB#_Y`Y\08[%N(WQ#M5DU'S9<5@<XD?&`:Q+X\"Z
MXY)\PN4_+/JA;&"S`8MO:PE#UF>OS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZ
MEPM_J9R;X:<""J/@^TD````````````````````````````````(`P``$@``
M``````````````````````"$`P``$@````````````````````````#8`@``
M$@````````````````````````#?`@``$@````````````````````````!V
M`P``$@````````````````````````"%`@``$@``````````````````````
M```1````(``````````````````````````P`P``$@``````````````````
M``````!(`P``$@````````````````````````!!`P``$@``````````````
M```````````H`P``$@````````````````````````#3````$@``````````
M```````````````Z`P``$0````````````````````````"]`0``$@``````
M``````````````````!S`@``$@````````````````````````"2`@``$@``
M``````````````````````"O````$@`````````````````````````X`0``
M$@````````````````````````!8`P``$@````````````````````````#1
M`@``$@````````````````````````#D`0``$@``````````````````````
M```M`0``$0`````````````````````````/`P``$@``````````````````
M``````"A`0``$@`````````````````````````"`0``$0``````````````
M``````````!A`0``$@````````````````````````"*`@``$@``````````
M``````````````":`P``$@````````````````````````#F`@``$@``````
M``````````````````#A````$@````````````````````````#K`0``$@``
M``````````````````````!<`@``$@````````````````````````"(`0``
M$@````````````````````````#8`0``$@`````````````````````````J
M`@``$@````````````````````````#"`@``$@``````````````````````
M``";`@``$@````````````````````````"D`@``$@``````````````````
M```````^`@``$@````````````````````````!O`0``$@``````````````
M```````````M````(`````````````````````````"M`P``(0``````````
M``````````````",`P``$@````````````````````````#V`0``$0``````
M``````````````````!X````$@````````````````````````!1`P``$@``
M``````````````````````#Z`@``$@`````````````````````````/`0``
M$@````````````````````````"3`P``$@`````````````````````````/
M!```$@````````````````````````#T`@``$@``````````````````````
M``"^````$@````````````````````````"6`0``$@``````````````````
M```````=`P``$@````````````````````````!.`0``$@``````````````
M```````````]`0``$@````````````````````````!J````$@``````````
M``````````````!L`P``$@````````````````````````!"`0``$@``````
M``````````````````#-`0``$@`````````````````````````<`0``$@``
M``````````````````````!E`P``$@````````````````````````"O`0``
M$@````````````````````````">````$@````````````````````````!D
M`@``$@````````````````````````#*`@``$@``````````````````````
M``"L`P``$0````````````````````````"N`P``$0``````````````````
M```````\````(`````````````````````````!$`@``$@``````````````
M``````````#S````$@````````````````````````!_`0``$@``````````
M``````````````#M`@``$@````````````````````````"'````$@``````
M``````````````````!0````(`````````````````````````!+`@``$@``
M``````````````````````"U`@``$@````````````````````````"\`@``
M$@`````````````````````````8!```$F`,`,!C`!``````Z`````````#F
M`P``$F`-`-!G`!`````````````````]!```$F`,`/!1`!``````?`P`````
M``"G`P``$F`,```?`!``````)`,```````#L`P``$F`,`+!'`!``````&```
M``````"K!```$F`,`-!'`!``````E`(```````#8!```$F`,`+!D`!``````
M>`````````"E!```$F`+`+`:`!````````````````#T!```$F`,`'!>`!``
M````2`4```````#+`P``$``6`)"P`1`````````````````D!```$@`,`'!*
M`!``````7`````````!7!```$0`.`!AH`!``````!`````````#7`P``$``7
M`/#"`1````````````````"C!```$F`,`+!%`!``````9`````````"X!```
M$F`,`!!0`!``````U`$```````#*!```$F`,`/!.`!``````O`````````!*
M!```$``4``"P`1`````````````````Q!```$F`,`-!*`!``````X`$`````
M``#$`P``$``5`)"P`1````````````````",!```$0`4`!BP`1``````"```
M``````#<`P``$@`,`'!F`!``````$`````````!\!```$F`,`)!E`!``````
MU`````````!0!```$F`,`"0B`!``````1`````````!,!```(``4``"P`1``
M``````````````#]`P``$F`,`+!/`!``````5`````````!F!```$F`,`+!&
M`!``````_`````````"6!```$F`,`+!,`!``````-`(`````````;&EB<&5R
M;"YS;RXU+C(P`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?
M<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A
M=F5?9&5S=')U8W1O<E]X`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V
M7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N
M97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A
M9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R
M;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R
M7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C
M:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED
M`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?
M8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?
M7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC
M<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E
M`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QI
M8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`7U]L:6)C7V-S
M=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A
M<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R
M7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P
M871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C$W``````(``@`"``(`
M`@`"`````@`"``(``@````(````"``(```````(``@`"`````@`````````"
M``(``@```````P```````P`"``(``@`#```````"``(```````(``@````(`
M`@`"```````"`````@````(``````````@```````P`"``(``@````,`````
M``(```````,``@`"``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``````````$``0`:`@``$````"````"7
MD98&```#``H%`````````0`!`&D"```0`````````)>1E@8```(`"@4`````
M```HL`$0`````"8````I``````````````!0L`$0`````"8```!$````````
M``````!8L`$0`````"8````6``````````````!@L`$0`````"8````.````
M``````````!HL`$0`````"8````-``````````````!PL`$0`````"8```!`
M``````````````!XL`$0`````"8````W``````````````"`L`$0`````"8`
M```9``````````````"(L`$0`````"8````L``````````````"@L`$0````
M`!4````!``````````````"HL`$0`````!4````"``````````````"PL`$0
M`````!4````#``````````````"XL`$0`````!4````$``````````````#`
ML`$0`````!4````%``````````````#(L`$0`````!4````&````````````
M``#0L`$0`````!4````(``````````````#8L`$0`````!4````)````````
M``````#@L`$0`````!4````*``````````````#HL`$0`````!4````+````
M``````````#PL`$0`````!4````,``````````````#XL`$0`````!4````.
M````````````````L0$0`````!4````/```````````````(L0$0`````!4`
M```0```````````````0L0$0`````!4````1```````````````8L0$0````
M`!4````2```````````````@L0$0`````!4````3```````````````HL0$0
M`````!4````4```````````````PL0$0`````!4````5```````````````X
ML0$0`````!4````7``````````````!`L0$0`````!4````8````````````
M``!(L0$0`````!4````:``````````````!0L0$0`````!4````;````````
M``````!8L0$0`````!4````<``````````````!@L0$0`````!4````=````
M``````````!HL0$0`````!4````>``````````````!PL0$0`````!4````?
M``````````````!XL0$0`````!4````@``````````````"`L0$0`````!4`
M```A``````````````"(L0$0`````!4````B``````````````"0L0$0````
M`!4````C``````````````"8L0$0`````!4````D``````````````"@L0$0
M`````!4````E``````````````"HL0$0`````!4````F``````````````"P
ML0$0`````!4````G``````````````"XL0$0`````!4````H````````````
M``#`L0$0`````!4````I``````````````#(L0$0`````!4````K````````
M``````#0L0$0`````!4````M``````````````#8L0$0`````!4````N````
M``````````#@L0$0`````!4````O``````````````#HL0$0`````!4````P
M``````````````#PL0$0`````!4````Q``````````````#XL0$0`````!4`
M```R````````````````L@$0`````!4````S```````````````(L@$0````
M`!4````T```````````````0L@$0`````!4````U```````````````8L@$0
M`````!4````V```````````````@L@$0`````!4````W```````````````H
ML@$0`````!4````X```````````````PL@$0`````!4````Y````````````
M```XL@$0`````!4````Z``````````````!`L@$0`````!4````[````````
M``````!(L@$0`````!4````\``````````````!0L@$0`````!4````]````
M``````````!8L@$0`````!4````^``````````````!@L@$0`````!4````_
M``````````````!HL@$0`````!4```!```````````````!PL@$0`````!4`
M``!!``````````````!XL@$0`````!4```!"``````````````"`L@$0````
M`!4```!&``````````````"(L@$0`````!4```!'``````````````"0L@$0
M`````!4```!(``````````````"8L@$0`````!4```!)``````````````"@
ML@$0`````!4```!*``````````````"HL@$0`````!4```!,````````````
M``"PL@$0`````!4```!-``````````````"XL@$0`````!4```!.````````
M````````````````````````````&`!!^*"!@NFF`XE](`2`3@(00#P@,$(X
MI@((?!```?BA_R'X````8`B``N@``*`O#`#^0<W__TL8`$'H8``A.!```>BF
M`PA\(`"`3@``````````````````````````&`!!^#B"@NFF`XE](`2`3A@`
M0?BX@8+II@.)?2`$@$X8`$'XR(""Z:8#B7T@!(!.&`!!^(B"@NFF`XE](`2`
M3A@`0?AX@H+II@.)?2`$@$X8`$'XX(""Z:8#B7T@!(!.&`!!^(""@NFF`XE]
M(`2`3A@`0?C8@8+II@.)?2`$@$X8`$'X2(&"Z:8#B7T@!(!.&`!!^/B!@NFF
M`XE](`2`3A@`0?@P@8+II@.)?2`$@$X8`$'X"(*"Z:8#B7T@!(!.&`!!^""!
M@NFF`XE](`2`3A@`0?A8@8+II@.)?2`$@$X8`$'XL(&"Z:8#B7T@!(!.&`!!
M^*B!@NFF`XE](`2`3A@`0?CH@8+II@.)?2`$@$X8`$'X*(*"Z:8#B7T@!(!.
M&`!!^#""@NFF`XE](`2`3A@`0?B0@8+II@.)?2`$@$X8`$'X&(&"Z:8#B7T@
M!(!.&`!!^!"!@NFF`XE](`2`3A@`0?BX@(+II@.)?2`$@$X8`$'X4(*"Z:8#
MB7T@!(!.&`!!^"""@NFF`XE](`2`3A@`0?B(@8+II@.)?2`$@$X8`$'X\(""
MZ:8#B7T@!(!.&`!!^&""@NFF`XE](`2`3A@`0?B@@(+II@.)?2`$@$X8`$'X
MB(""Z:8#B7T@!(!.&`!!^`B!@NFF`XE](`2`3A@`0?A8@H+II@.)?2`$@$X8
M`$'XZ(""Z:8#B7T@!(!.&`!!^/B`@NFF`XE](`2`3A@`0?@X@8+II@.)?2`$
M@$X8`$'X>(&"Z:8#B7T@!(!.&`!!^%"!@NFF`XE](`2`3A@`0?AP@8+II@.)
M?2`$@$X8`$'XT(""Z:8#B7T@!(!.&`!!^!""@NFF`XE](`2`3A@`0?C`@(+I
MI@.)?2`$@$X8`$'X0(&"Z:8#B7T@!(!.&`!!^("`@NFF`XE](`2`3A@`0?B0
M@H+II@.)?2`$@$X8`$'XR(&"Z:8#B7T@!(!.&`!!^+"`@NFF`XE](`2`3A@`
M0?B0@(+II@.)?2`$@$X8`$'XF(*"Z:8#B7T@!(!.&`!!^*B`@NFF`XE](`2`
M3A@`0?B8@(+II@.)?2`$@$X8`$'X&(*"Z:8#B7T@!(!.&`!!^)B!@NFF`XE]
M(`2`3A@`0?A@@8+II@.)?2`$@$X8`$'X`(&"Z:8#B7T@!(!.&`!!^,"!@NFF
M`XE](`2`3A@`0?AP@H+II@.)?2`$@$X8`$'X\(&"Z:8#B7T@!(!.&`!!^-"!
M@NFF`XE](`2`3A@`0?AH@H+II@.)?2`$@$X8`$'X0(*"Z:8#B7T@!(!.&`!!
M^&B!@NFF`XE](`2`3A@`0?@H@8+II@.)?2`$@$X8`$'X@(&"Z:8#B7T@!(!.
M&`!!^."!@NFF`XE](`2`3@(00#P@,$(XI@((?/#_P?OX_^'[$``!^&'_(?AP
M`('X:`"A^'``@3AH`*$X?`!AD'P`83CPCRWIB``A^0``(#FA_/]+&`!!Z```
M`&!8@(+H````8%"`8NAX(X5\W44`2````&````!@8(`BZ0``R8L``)XOZ`&>
M00```&`X@.+K``!_@,W]_TL8`$'H>!MJ?```?X`Z!BJ)`@`I83H&*IFQ_?]+
M&`!!Z/[_(CW09(SQT#AIP7P`(8$%`"DYM`<I?6``(?D``$)@8``!R#H&(XD!
M`"EAH`5`\3H&(YDJ8(K]`%B,_^0!G4%@``'8``!"8&``@>@D'X-XR?[_2Q@`
M0>A\`*&`<``!Z?__0CWX?TKI_O\B/?[_XCQP/"DY:#SG.````&!X&VM\`0"%
M+P``R.@0`$/Y````8!@`(_D$`"`YN))B^`@`X_@``,/XL)(BD00`Q3A,`)U`
M^O\F.04`0#D@`"EY`0`I.:8#*7T4``!(````8````&````!@``!"8`D`Z.BT
M!TE])!\I>0$`2CGX_RDY(`!*>2I)ZWSD_P!"M`?)?````&#(DF+H``!`.20?
M*7D#`*4X^/\I.?[_@CP`%H0XM`>E?'A;9GT``.`X*DE+?3W[_TL8`$'H>1M_
M?+@`@D$```!@R))BZ````&"H@L([S?K_2Q@`0>C^_V(\A`"!.,`Y8SC1&0!(
M``"C+Z``GD$```!@R))BZ/7[_TL8`$'H3?S_2Q@`0>AX^^-_B`!!Z?"/C>AY
M(DI]``"`.,0`PD"@`"$X$``!Z/#_P>OX_^'KI@,(?"``@$[E^_]+&`!!Z```
M`&```*,OR))B^)P`WD$M^_]+&`!!Z````&`X@.+K``!_@,G[_TL8`$'H'0K#
MF^S]_TL```!@R))BZ-'\_TL8`$'H>!M_?#C__TL```!@P))BZ```HR\D`)Y!
M"4(`2%#__TL```!@:(""Z/[_8CQ@/&,X*?K_2Q@`0>C^_V(\A`"!.$@Y8SCM
M&`!(``"C+Q@0?O@<__Y!S4$`2!3__TN-^O]+&`!!Z`$`8#CQ^_]+&`!!Z```
M```````!@`(```(00#P@,$(X>`LI?.0&(7@````X@?\A^*8#"'P```'X$(`"
MZ=CZ_TL```!@``````````!`(`P`+`````8`7W-T87)T````8````&`"$$`\
M(#!".````&````!@!X`B.0"`8CA02"-]#@"I*R``G4P```!@&(`BZ0``J2\@
M`)Y-I@((?'A++'VF`RE]$``!^.'_(?@8`$'X(02`3A@`0>@@`"$X$``!Z*8#
M"'P@`(!.````8````&```$)@`A!`/"`P0C@```!@````8`"`@C@`@&(X4""#
M?'0>A'QT#H1\E0&$?"``@DT```!@((!"Z0``JB\@`)Y-I@((?'A33'VF`TE]
M$``!^.'_(?@8`$'X(02`3A@`0>@@`"$X$``!Z*8#"'P@`(!.``!"8`(00#P@
M,$(X````8*""(HD``(DO(`">3*8""'P0``'XX?\A^`7__TL@`"$X`0`@.0``
M`&`0``'HH((BF:8#"'P@`(!.````8````&```$)@`A!`/"`P0CC__R(]F'TI
M.7A+(WT``"/I``"I+Q0`GD`H__]+````8````&```$)@````8"B`(ND``*DO
MY/^>0:8""'QX2RQ]I@,I?1```?CA_R'X&`!!^"$$@$X8`$'H(``A.!```>BF
M`PA\W/[_2P```&````!@````8````&`"$$`\(#!".*8""'S(_R'[T/]!^P@`
M0#FF`TE]V/]A^^#_@?LP`(,YZ/^A^_#_P?OX_^'[$``!^!'](?CPCRWIJ`(A
M^0``(#DH`,$X``!"8`D`+.D0`,8X(@`J>>1%)7GD141Y'@*K5`+")WDHP"5Y
M(,(H>1X"A%0HP$IY>"ME?2X$YU1X4XI\+@0(57@[IWQX0TI](D8E>2!&*7EX
M*^=\>$M)??#_YOCX_R;YI/\`0D``(#F(``$YI@,I?0``0F`(``@YV/_(Z```
M*.FH_^CHF/](Z7A*R7QX.BE]>%(I?<(/*GFD#REY>$M)?2``*7D8`"CYS/\`
M0@``P^@@``/H*`!!Z0@`H^@0`(/H&`!CZ<(NR'BD+LEX%%)`?7A+"7V"6DH]
M>"A^?9EY2CDX*(A\(``I>63PIW@42BI]>$/*?Q1227TP`"'I@O"_>'@[_W\@
M`%YY(`#_>W@PB'P42BM].##G?X):*3UX0^A\*"C;>\(NQWN"\-QX9/#=>)EY
M*3D40BE]>#MH?WCKAW\X`*'K%$(I?2``YWAX\/M_.#A(?2``/'D4ZJ1_>$-J
M?X):O3\H*)M[F7F].\(NB'L44EU]@O#=>RCPWGMX0VA_>.O,?T``P>L40DI]
M>.#[?#A@*'UX0VE_@EJ^/R``7GF9>;T[PB[(>Q3Z_7\H*-U[%$H_?7A#OW^"
M\)U[*/"(>WCK''U(``'I%/HI?2``/WEX\)M]@EJH/SC@2'V9>;T[>$-J?Q0Z
M_7S"+NA[*"C]>Q121WUX0ZA_*/#'>X+PW7L40DI]>.O^?%``X>AX^)M_./`H
M?7A#:7^"6J<_(`!'>9EYO3O"+NAX%&*]?R@H^W@42CU]>$-]?X+P^WLH\.A[
M>-L??5@``>D4ZBE](``]>7@XVW^"6H@]./A(?7A#:G\H*+M[PBZH>YEYC#EX
M0VA_@O#[>"CPYW@4XHQ_>-O[?&``X>@44EQ]%$)*?7CH_'\XV"A]@EJ'/2``
M1WF9>8PY>$.)?Q3RS'_"+NAX*"C\>!1*/GUX0YY_@O"\>RCPJ'L4\BE]>.,=
M?6@``>D@`#YY>#A\?X):B#TXZ$A]>$.*?R@HW'O"+LA[F7F,.7A#B'^"\/QX
M*/#G>!3Z[']XX_Q\<`#AZ!127WT40DI]>/"_?SC@*'V"6H<](`!'>9EYC#EX
M0^E_%-IL?\(NZ'@H*/]X%$H[?7A#_W^"\-M[*/#(>Q3Z*7UXVQY]>``!Z2``
M.WEX.)]_@EJ(/3CP2'UX0^I_*"A_>\(N:'N9>8PY>$/H?X+P_W@H\.=X%.JL
M?WC[_WR``.'H%%)=?11"2GUXV-U_./@H?8):AST@`$=YF7F,.7A#J7\4XHQ_
MPB[H>"@H_7@42CQ]>$.]?X+P?'LH\&A[%.HI?7CC&WV(``'I(``\>7@X_7^"
M6H@].-A(?7A#JG\H*)U[PBZ(>YEYC#EX0ZA_@O#]>"CPYW@4\LQ_>.O]?)``
MX>@44EY]%$)*?7C@?G\XZ"A]@EJ'/2``1WF9>8PY>$/)?Q3Z['_"+NAX*"C^
M>!1*/WUX0]]_@O">>RCPB'L4^BE]>/,<?9@``>D@`#]Y>#B^?WCXFG^"6H@]
M..!(?7A#RG\H*/Y[PB[H>YEYC#EX0\A_@O#^>"CPYW@4VFQ_>//^?*``X>@4
M4EM]%$)*?3CP*'UX0TE_@EIG/R``1WF9>7L[PB[H>!3JNW\H*/MX%$H]?7A#
M?7^"\/M[*/#H>WC;'WVH``'I%.HI?2``/7EX.-I_@O#L>"CPYWB"6@@]>&/L
M?)EY:#LX^$A]%.*;?WA#2G\H*+M[PBZH>WA#:'\44EQ]%$)*?;```>EXZ/M_
M(`!'>8):"#V9>8@[.&`H?13RW']X0VE_*"C\>,(NZ'AX0XA_%$H^?11"*7VX
M``'I@O"^>RCPO7MX.)M]>/.^?R``/7F"6H@_./!(?9EYG#MX0VI_%/J<?R@H
MNWO"+JA[%%)<?7A#:'^"\/]X%$)*?<```>ED\.=X>#O_?R``7'D@`/M[>.C:
M?X):"#TH*)E[F7GH.#C8*'T48H=]>$-)?X+PIWO"+II[9/"H>Q1*+'UX0^=\
M>-,H?Q1"*7W(``'I>/K_?"``/7EX4NI_PBZZ>R@HN7O:;@@](`!*>:'K"#D4
M\NA_@O"(>Q127WUXTS]_%/I*?=``X>MD\)Q[>.,(?2``7GEX.AQ]*"C:>]IN
M_S]X2HE_H>O_.\(NW'L4VG]_(``I>8+POWMD\+U[>.O_?Q1*.WUXXUU_(`#G
M>!3J*7W8`*'K(``\>2@HFWO:;IT]>$+]?WA2JG^AZXPY%#J,?<(NG7N"\,=[
M(`!*>63PWGL44DQ]>//G?'CK?G\4\DI]X`#!ZWCZ^GP@`%UY>$I)?R``*7F"
M\(Q[VF[>/V3PG'NAZWX[(``>>13RVW_"+JA[*"B[>Q1*/GUX0VA_>..,?11"
M*7WH``'I>#J>?2``/'D@`/][>%+*?R@HFWO:;@@]PBZ>>Z'K"#D@`$IY%/H(
M?8+POWL44DA]>/-H?Q1"2GWP``'I9/"]>WCK_W\@`%YY>&+]?R``YWC:;@@]
M>$JI?Z'K"#DH*-M[%#KH?"``*7G"+LA[%$HG?7A#:'^"\)U[%$(I??@``>ED
M\)Q[>..]?R``)WEX^KQ_(`",>=IN"#UX4HI_H>L(.<(N_'@48@A]*"C[>"``
M2GF"\,Q[%%)(?7CC:'\40DI]``$!Z63PWGMX\XQ](`!;>2``_WLH*'Q[VF[(
M/WCJB'UX2@E]H>O>.Q3ZWG_"+FA[(``I>7A#B'\42CY]@O#_>!1"*7T(`0'I
M9/#G>'@[_W\@`#QY>&+^?R``IWO:;@@]>%+*?Z'K"#DH*)U[%#H(?2``2GG"
M+H=[%%)(?7@[J'^"\'Y[%$)*?1`!`>ED\'M[>-O>?R``C'EX^L=_(`!;>=IN
M"#UX2NE\H>L(.2@H>GL48HA](``I><(N:'L42BQ]>$-(?X+PAWL40BE]&`$!
MZ63PG'MXX_U\(`#_>WCRIW\@`#QYVFX(/7A2ZGRAZP@YPBZ'>Q3Z"'TH*)I[
M(`!*>8+P?WL44DA]>#M(?Q1"2GT@`0'I9/![>WC;_W\@`-Y[(`!;>=INZ#QX
MZNA_>$H)?:'KYS@4\N=\*"AZ>\(N:'L@`"EY>$-(?Q1*)WT40BE]*`$!Z8+P
MGGMD\)Q[(`"G>WCCWG\@`#QY>/K:?]IN"#UX4DI_H>L(.10Z"'W"+IU[*"B:
M>R``2GD44DA]>.M(?Q1"2GTP`0'I@O!G>V3P>WL@`%UY>-OG?"``_WO:;H@]
M>/+H?'A*"7VAZXPY%/J,?2@HNWO"+JA[(``I>7A#:'\42BQ]%$(I?3@!`>F"
M\)][9/"<>R``.WEXX_]_(`#>>W@Z_'_:;@@]>%**?Z'K"#D4\@A]PBY\>R@H
M>GL@`$IY%%)(?7CC2'\40DI]0`$!Z8+POGMD\+U[(`!<>7CKWG\@`.=X>/K=
M?]IN"#VAZP@Y>$JI?Q0ZZ'S"+II[*"B(>R``*7EXTPA]%$HG?11"*7U(`0'I
M@O!]>V3P>WL@`"=Y>-N]?R``_WMX\KM_VFX(/7A2:G^AZP@Y%/H(?<(N^W@H
M*/IX(`!*>1122'UXVTA_%$)*?5`!`>F"\)][9/"<>R``6WEXX_]_(`#>>]IN
MB#UXZNA_>$H)?:'KC#D4\HQ]*"A\>\(N:'L@`"EY>$.(?Q1*+'T40BE]6`$!
MZ8+P_GAD\.=X(``\>7@[WG]X^MI_VF[H/'A22G\@`*A[H>OG.,(NG7L40N=\
M*"B:>R``2GF"\&A[%%)'?7CK1W\4.DI_8`'AZ&3P>WMXVPA](`!=>X+PBGL@
M`/][VFYG/WCR!WVAZWL[>$KI?&3PG'L4^OM_>.-*?2@HNWL@`"=YPBZ\>Q0Z
M_WQXXWQ_%.)G?QN/(#UH`8'K>$-??=R\*6$@`"EY./A:?SA`7WT@`&Q[%.*)
M?WC[7W^"\*=[(`#>>V3PO7L4\MQ_>.OG?"@HG'G"+IUY(`#_>Q3Z_G]XZYU_
M%.J??W`!H>MX4_Y\./![?SA0_GP@`!]Y>/-^?Q3JJ7^"\)MY9/"(>13Z_7]X
M0VA_(`#>>R``FGL4\O]_>#L>?2@H6WLX\)Q_PBY=>W@!P>MXZWU_(`!,>13J
MOW\X.!]](`"[>Q3RR7]X^Y]_9/!*>X+P7'L48IY]>%.*?\(N?GLH*'Q[(`#_
M>WCSG']X0UY]./"]?X`!P>L4^HQ]%.*,?SA`7WT@`)I[(`#L>!3RR7]X^[]_
M9/!G>X+P?7MX.Z=_%&*>?2@H77O"+EY[>/.]?WA3_GPX\)Q_(`#_>X@!P>L4
M^HQ].%#_?!3JK']X^Y]_(`"[>Q3RR7^"\%Q[(``,>63P2'L48IY]>$.(?\(N
M?GLH*'Q[(`#_>WCSG']X.QY]./"]?Y`!P>L4^HQ]%.*,?S@X'WT@`)I[(`!,
M>13RR7]X^[]_9/!J>X+P?7MX4ZI_%&*>?2@H77O"+EY[>/.]?WA#7GTX\)Q_
M(`#_>Y@!P>L4^HQ].$!??13JK']X^Y]_(`"[>Q3RR7^"\%Q[(`#L>&3P1WL4
M8IY]>#N'?\(N?GLH*'Q[(`#_>WCSG']X4_Y\./"]?Z`!P>L4^HQ]%.*,?SA0
M_WP@`)I[(``,>13RR7]X^[]_9/!H>X+P?7MX0ZA_%&*>?2@H77O"+EY[>/.]
M?W@['GTX\)Q_(`#_>Z@!P>L4^HQ].#@??13JK']X^Y]_(`"[>Q3RR7^"\%Q[
M(`!,>63P2GL48IY]>%.*?\(N?GLH*'Q[(`#_>WCSG']X0UY]./"]?[`!P>L4
M^HQ]%.*,?SA`7WT@`)I[(`#L>!3RR7]X^[]_9/!G>X+P?7MX.Z=_%&*>?2@H
M77O"+EY[>/.]?WA3_GPX\)Q_(`#_>[@!P>L4^HQ].%#_?!3JK']X^Y]_(`"[
M>Q3RR7^"\%Q[(``,>63P2'L48IY]>$.(?\(N?GLH*'Q[(`#_>WCSG']X.QY]
M./"]?\`!P>L4^HQ]%.*,?S@X'WT@`)I[(`!,>13RR7]X^[]_9/!J>X+P?7MX
M4ZI_%&*>?2@H77O"+EY[>/.]?WA#7GTX\)Q_(`#_>\@!P>L4^HQ].$!??13J
MK']X^Y]_(`"[>Q3RR7^"\%Q[(`#L>&3P1WL48IY]>#N'?\(N?GLH*'Q[(`#_
M>WCSG']X4_Y\./"]?]`!P>L4^HQ]%.*,?SA0_WP@`)I[(``,>13RR7]X^[]_
M9/!H>X+P?7MX0ZA_%&*>?2@H77O"+EY[>/.]?W@['GTX\)Q_(`#_>]@!P>L4
M^HQ].#@??13JK']X^Y]_(`"[>Q3RR7^"\%Q[(`!,>63P2GL48IY]>%.*?\(N
M?GLH*'Q[(`#_>WCSG']X0UY]./"]?^`!P>L4^HQ]%.*,?SA`7WT@`)I[(`#L
M>!3RR7]X^[]_9/!G>X+P?7MX.Z=_%&*>?2@H77O"+EY[>/.]?WA3_GPX\)Q_
M(`#_>^@!P>L4^HQ].%#_?!3JK']X^Y]_(`"[>Q3RR7^"\%Q[(``,>63P2'L4
M8IY]>$.(?R``_WLH*'Q[PBY^>Q3ZC'UX\YY_%/*,?_`!P>MX.Q]]./B]?S@X
M'WT@`)I[(`!,>13RR7]X^[]_9/!J>X+P?7MX4ZI_%&*>?2``_WO"+EY[*"A=
M>Q3ZC'UX\[U_>$->?13J;'_X`:'K.$!??3CPG'\@`.=X(`!^>WC[C'\4ZJE_
M@O!<>V3P7WL4.OU\>/N??\(NW7LH*-Q[(`",>7CKG']X4_U_..A[?P`"H>L4
M8N=\%.*'?3A0YW\@`)QY>#MG?Q3J*7T@``AYPBZ=>R@HFGL40@E](`#G>!0Z
M"'V"\-M[>.M'?V3PWGL(`J'K8LH@/7CS>W_6P2EA%#KH?"``*7EX^FA_(`#^
M>!3JJ7]X8@A](`!*>2@HVGL44EU](``(><(NW7L40DI]>.M(?X+PF7L40@I]
M$`)!Z63PG'L@``QY>.,\?R``_WMXVIU_%%))?7@ZIW^"\-U[9/#>>Q3ZZG]X
M\[U_PBZ:>1@"P>L@`.IX*"B'>7C3YWP44E]]%#I*?7CBIW\@`%IY(`!_>Q3R
MR7]X0NA\%/K>?\(N6WLH*%E[9/"'>8+PGWD@``AY>#O_?Q1"'GUXVR=_(`">
M>Q0Z"'T@`N'H>.KY?R``&WF"\$Q[>%(J?\(N?'L4.NE\*"AY>Q3RYWQD\%Y[
M>/.>?2``2GDH`H'I%%)'?7CC)W]X^MI_%#I*?2``7'D@`*=[%&*)?7A"2'\4
M.HQ]*"B:>X+P>7O"+IU[9/!G>R``"'DP`F'K>#LG?WCK77\40@Q]>/+Z?!3J
M"'T4VFE_(``=>7A22G^"\(Q[(`#_>V3PG'L4^OM_>..,?<(NNWLX`H'K*"BZ
M>R``2GD44E]]>-M??Q3Z2GUX.IM](`!?>13BB7]X0FA_(`#>>X+PNWMD\+U[
M>.M[?Q3RW']``J'KPB[\>R@H^GL@``AY(`#G>!1"'GUXXUY_%/((?7AB?'\@
M`!YY%.JI?WA2BG^"\/Q[9/#_>Q0Z_7QX^YQ_PB[=>T@"X>LH*-I[(`!*>112
M1WUXZT=_%#I*?7C:G7\@`$=Y%/KI?R``C'EX0JA_@O#=>V3PWGMX\[U_%&+_
M?U`"P>O"+OIX*"CY>"``"'D40A]]>-,_?Q3Z"'UXXKE_(``:>2``?WL4\LE_
M>%(J?Q3ZWG_"+EM[*"A9>X+P_W@@`$IY9/#G>'@[_W\44EY]>-LG?R``GGL4
M.DI]6`+AZ'CJ^7\@`%MY@O!,>WA"*'_"+GQ[%#KI?"@H>7L4\N=\9/!>>WCS
MGGT@``AY8`*!Z11"!WUXXR=_>/K:?Q0Z"'T@`!QY(`"G>Q1BB7UX4DI_%#J,
M?2@HFGN"\'E[PBZ=>V3P9WL@`$IY:`)AZW@[)W]XZUU_%%),?7CR^GP4ZDI]
M%-II?R``77EX0DA_@O",>R``_WMD\)Q[%/K[?WCCC'W"+KM[<`*!ZR@HNGL@
M``AY%$(??7C;7W\4^@A]>#J;?2``'WD4XHE_>%)J?R``WGL4\MQ_*"C[>\(N
M_'L@`$IY%%)>?7CC?G]X`H'K@O"Z>V3PO7MXZUU_(`#G>!3BB7]X8KM_%#K\
M?!3R2GV"\/Q[9/#_>R``7GEX^YQ_@`+AZWA":'\H*-I[PB[;>R``"'D40@=]
M>-M'?Q0Z"'UXZIM_%/KI?R``C'D@``=Y%&+_?WA2:G^"\,Q[9/#>>\(N^WAX
M\XQ]*"CZ>(@"P>L@`$IY%%)??7C;7W\4^DI]>.*:?2``6WD@`+][%/+)?WA"
M2'\4^MY_PBYZ>R@H>7N"\/]X(``(>63PYWAX._U_%$(>?7C3)W]X8K]_%#H(
M?9`"X>@@`)Y[(``:>7A2ZG_"+EQ[*"A9>Q0ZZ7P@`$IY%/+G?&3P?WN"\'Y[
M%%)'?7CC)W^8`H'K>/O>?Q0Z2GUXZM]_(`!;>2``AWD4XHE_>$+_?Q0ZG'T@
M`/][PBYG>R@H:'L4^NQ_>#L(?8+P67MD\%Q[%$(??:`"X>MXXSQ_>/*'?R``
M"'EX4NI\*"@:>13Z*7T@`+][%/KI?\(N!WD@`$EY>#M'?RCP:GN"\'U[%$H_
M?10Z*7UXZT=]%#(I?10J2'T4`MY\%"('?11:_'P@`"EY(`!*>2``"'D@`.=X
M(`#&>```(_D(`$/Y$``#^1@`X_@@`,/XJ`)!Z?"/+>EY2DI]```@.3``PD#P
M`B$X$``!Z,C_(>O0_T'KV/]AZ^#_@>OH_Z'K\/_!Z_C_X>NF`PA\(`"`3MWA
M_TL8`$'H``````````&`!P``````8```0F`"$$`\(#!".```(RPX`8)!I@((
M?-#_0?O8_V'[X/^!^^C_H?OP_\'[^/_A^P```&`P@"+I$``!^+'_(?@``&GK
M``"[+Y``GD$``".)``"I+^P`GD$]`(DO``#`.R0`GD%X&WY\`0`^C0``*2\]
M`(DO"`":0?#_GD!0\,-_M`?>?P``^^L``+\O3`">07@CFGQX&WQ\>-M]?P``
M`&```$)@>/OC?WCCA']X\\5_)>#_2Q@`0>@``*,O$`">0*[P/WT]`(DO/`">
M00D`_>L``+\OT/^>0%``(3@``&`X$``!Z-#_0>O8_V'KX/^!Z^C_H>OP_\'K
M^/_AZZ8#"'P@`(!.4.B[?U``(3AT'KU_`0!^.!0:?WP``+J3$``!Z-#_0>O8
M_V'KX/^!Z^C_H>OP_\'K^/_AZZ8#"'P@`(!.``#`.T#__TL``&`X(`"`3@``
M```````!@`8``````&```$)@`A!`/"`P0CBF`@A\^/_A^W@;?WP0``'X@?\A
M^/"/+>EH`"'Y```@.7C[XW]D`($X>?[_2P``HR]<`)Y!``!"8&8`0>D```!@
M,(`BZ0``">DD'TIY%%(H?0D`Z>@``*<O*E'H?,3_GD$```!@``!"8`D`2>D`
M`*HO^/])^?3_GD!X^^-_9`"!."'^_TL``*,OL/^>0&@`(>GPCTWI>5(I?0``
M0#D8`,)`@``A.!```>CX_^'KI@,(?"``@$ZEW_]+&`!!Z``````````!@`$`
M``(00#P@,$(XI@((?.#_@?OH_Z'[>!M]?/#_P?OX_^'[R/\A^]#_0?O8_V'[
M$``!^%'_(?@``"2)\(]-Z6@`0?D``$`Y/0`I:30`*7U^V2E5(``I>11*Q']X
M\\-_M>#_2Q@`0>AD`($X>!M\?'CKHW]I_?]+>1M_?(@!@D&5X/]+&`!!Z"``
MB7M`2*-_1`&<0&0`X8,```!@,(!BZP``/8D``*DO*`*>03T`B2\@`IY!>.NJ
M?Q0``$@```!@``!"8#T`B2\0`)Y!`0`JC0``J2_P_YY`4%!=?2``27D"`%PY
M``";ZR0?_WL42FI\(`!C>&'>_TL8`$'H``"C+RKY?'S@`=Y!9`!!@0``/8D`
M`!OI)!]*>0``J2\J4$A]```JF3@`GD$]`(DO,`">07CKJ'\8``!(````8```
M`&```$)@/0")+Q0`GD$!`"B-``"I+P$`*IWL_YY`/0`@.?__GC@``"J9````
M8````&```$)@`0`DC0``J2\!`"J=]/^>0```8#AH`"'I\(]-Z7E2*7T``$`Y
M5`'"0+``(3@0``'HR/\AZ]#_0>O8_V'KX/^!Z^C_H>OP_\'K^/_AZZ8#"'P@
M`(!.````8````&```$)@__^>./__7SD```!@``!"8`$`)(T``*DO`0`JG?3_
MGD"0__]+````8````&```$)@````8#"`8NL``#OK```YZ0``J2_``)Y!>,LJ
M?P``X#L)`"KI`0#_.[0'_W\``*DO\/^>0`(`/SFT!RE])!\D>0```&"H@D*!
M``"*+T0`GD%XRR-_W=W_2Q@`0>@``*,O``![^'P`WD$!`#\Y``!`.20?*7D@
M`/][*DE#?60`X9,<_O]+````8````&```$)@`0`@.0```&!X(X-\J((BD;'<
M_TL8`$'H>1MZ?#0`@D%XRR1_)!_E>QG=_TL8`$'H``!;^WC30W^@__]+```@
M.0S^_TL0`(`X``#@.V3__TO__V`XH/[_2ZG<_TL8`$'H``````````&`!P``
M``!"8`(00#P@,$(XI@((?.C_H?O8_V'[>1M]?.#_@?OP_\'[^/_A^Q```?C1
M_B'X\(\MZ?@`(?D``"`Y$`""00``/8D``(DO/`">0/@`0>GPCRWI>4I*?0``
M(#EP`<)`,`$A.!```>C8_V'KX/^!Z^C_H>OP_\'K^/_AZZ8#"'P@`(!.H=K_
M2Q@`0>AY&WY\O/^"0?[_8C_8.'L[>//#?X7=_TL8`$'H>1M_?,@`@D$3`#^)
M+@")+]P`GD%XZZ-_$P#_.U'=_TL8`$'H>!M\?'C[XW]!W?]+&`!!Z!3B8WP"
M`&,XM`=C?&W;_TL8`$'H`0"`./__H#AXVV9_>.NG?WC[Z']X&WQ\O=O_2Q@`
M0>@!`&`X>..$?V@`H3BYW/]+&`!!Z/__@R]XXX-_%`">08``(8$F!"E5`$")
M*X@`GD%UW/]+&`!!Z'CC@W]IVO]+&`!!Z'CSPW_-W/]+&`!!Z'D;?WQ,_X)`
M````8````&```$)@>//#?VW=_TL8`$'H>.NC?W'=_TL8`$'HP/[_2P``0F`4
M`#^)``"I+P#_GD$N`(DO&/^>0!4`/XD``(DO[/[^00C__TL```!@````8```
M0F!)_O]+@/__2\G:_TL8`$'H``````````&`!0````!"8`(00#P@,$(XI@((
M?.C_H?OP_\'[^/_A^P```&`X@.+K$``!^,'_(?@``'^`1=O_2Q@`0>C@`"/I
M``!_@`@`J>LQV_]+&`!!Z*T`PXL``'^`(=O_2Q@`0>A@!MY["``CZ2``*>DP
M/"E5>/,^?0(`W;,``'^`_=K_2Q@`0>C@`"/I``!_@`@`R>OIVO]+&`!!Z/[_
M@CP``*`X6#R$.$7;_TL8`$'H*`!^^```?X#%VO]+&`!!Z.``(^D``'^`"`#)
MZ[':_TL8`$'H$`@CZ0``?X`P`#[YG=K_2Q@`0>C@`"/I``!_@`@`R>N)VO]+
M&`!!Z```0#F``2/I``"I+Q@`GD$``'^`;=K_2Q@`0>B``2/IJ`!)Z3@`7OD`
M`'^```#`.U':_TL8`$'HX``CZ0``?X`(`"GI0`#)^SG:_TL8`$'HX``CZ0``
M?X`(`"GI(`#)^R':_TL8`$'HX``CZ0``?X`(`.GK#=K_2Q@`0>A``"$X.`,C
MZ4@`/_D0``'HZ/^AZ_#_P>OX_^'KI@,(?"``@$X``````````8`#`````$)@
M`A!`/"`P0CBF`@A\\/_!^_C_X?MX&WY\````8#B`XNL0``'XT?\A^```?X"E
MV?]+&`!!Z'CSQ'^8`:,X`0!@.-'7_TL8`$'H``"C+R0`GD$P`"$X``!@.!``
M`>CP_\'K^/_AZZ8#"'P@`(!.``!"8```?X!=V?]+&`!!Z+`!(X$F!"E5`$")
M*R0`GD$``'^`0=G_2Q@`0>BP`2.!)@0I5?__*FT`H(HOJ/^>0'CSPW\"`(`X
MO=?_2Q@`0>@P`"$X$``!Z#0`8WSP_\'K^/_AZW[98U2F`PA\M`=C?"``@$X`
M`````````8`"`````$)@`A!`/"`P0CBF`@A\Z/^A^_#_P?MX&WY\^/_A^_[_
M8CQX(YU\X#AC./\/H#@0``'XL>\A^"@`@3CPCRWI*!`A^0``(#FMU_]+&`!!
MZ+0'8WP``(,OK`"=0/__XSLP$"$YM`?_?Q3Z27WX[TJ)``"*+X``GD%X&W]\
M*`!A."\`@#AX^^5__=?_2Q@`0>@``*,O<`">00```&`X@"+I``!I@$'8_TL8
M`$'H>//$?R@`H3AX^^9_?=G_2Q@`0>@H$"'I\(]-Z7E2*7T``$`Y7`#"0%`0
M(3@0``'HZ/^AZ_#_P>OX_^'KI@,(?"``@$X``$)@``"_+X3__D````!@``!"
M8````&`X@"+I``!I@-77_TL8`$'H>//$?WCKI7]%V?]+&`!!Z)C__TOYUO]+
M&`!!Z``````````!@`,`````0F`"$$`\(#!".*8""'P```!@.(`BZ1```?CA
M_R'X``!I@('7_TL8`$'H````8$"`HNC^_X(\_O_"//`XA#@`.,8XD=C_2Q@`
M0>@@`"$X$``!Z*8#"'P@`(!.``````````&`````````8````&```$)@`A!`
M/"`P0CBF`@A\^/_A^P```&`X@.+K$``!^-'_(?@``'^`#=?_2Q@`0>AM__]+
M``!_@/W6_TL8`$'H_O_"//[_@CQ8/,8X_O^B/!`YA#A0+J4X>#/'?````#FE
MU?]+&`!!Z#``(3@0``'H^/_AZZ8#"'P@`(!.``````````&``0``````8```
M`&```$)@`A!`/"`P0CBF`@A\\/_!^_C_X?L0``'X<=\A^/"/+>EX("'Y```@
M.0G6_TL8`$'H_O_"//[_`CUX&V=\`0"`.&@`83@!$*`X*#G&.#@Y"#G!U?]+
M&`!!Z```@R^$`)Q!:`!A.'`0@3@`$*`X1=7_2Q@`0>BT!W]\``"?+V0`G$$!
M`'\XM`=C?!G5_TL8`$'H>1M^?$P`@D%P$($X>/OE?U'6_TL8`$'H```@.7CS
MPW^N^3Y]>"!!Z?"/+>EY2DI]```@.20`PD"0("$X$``!Z/#_P>OX_^'KI@,(
M?"``@$X``&`XT/__2_G4_TL8`$'H``````````&``@````!"8`(00#P@,$(X
M`/__2P```````````````````&```$)@`A!`/"`P0CBF`@A\X/^!^^C_H?MX
M&WU\)H"0??C_X?NX_^'Z_O]B/'@CGWS`_P'[R/\A^T@Y8SC0_T'[V/]A^P@`
M@9'P_\'[$``!^$'O(?AD`($X\(\MZ6@0(?D``"`YJ?+_2R\`@#AX&WQ\>.NC
M?\'2_TL8`$'H``"C+V@`GD'^_V(\>.ND?U@Y8SBM]/]+>.NC?V@0(>GPCTWI
M>5(I?0``0#G<`<)`P!`A.!```>@(`(&!N/_AZL#_`>O(_R'KT/]!Z]C_8>O@
M_X'KZ/^AZ_#_P>OX_^'KI@,(?""!D'T@`(!.>.NC?_[_8C]5U?]+&`!!Z&@Y
M>SL``#PN>-MD?[0'>GQX^^-_"=7_2Q@`0>AY&W]\;/^"0?[_`C_^_R(_``#@
M.@$`6CMP.1@[>#DY.P"`]V(``,`[````8```0F```%^)``"*+PP`GD#^_^(_
M0#G_.QP`DD%XXX-_>/OD?V'5_TL8`$'H``"C+\``GD%X^^-_S=3_2Q@`0>BT
M!V-\%!H_??__*8DO`(DO(`">0/__0SEX^^5_M`=#?>X9Q7___Z6(+P"%+^C_
MGD$4&EI]_P^*+\S^G4%X^^=_`0"`.``0H#AXPP9_>,LH?WCKJ7]H`&$X'=/_
M2Q@`0>@```!@.(#BZP``?X"9T_]+&`!!Z&@`@3B8`:,X`0!@.`74_TL8`$'H
M``"C+R``GD```'^`<=/_2Q@`0>BP`2.!)@0I50"XB7\D`)Y!``!@.'C;9'_A
MT_]+&`!!Z```HR]X&W]\`/^>0#S^_TMH`&$X`0"`.-'1_TL8`$'H``"C+\S_
MGD#^_V(\:`"!.%@Y8SC-\O]+:`!A.+W2_TL8`$'H&/[_2T'2_TL8`$'H````
M``````.`"0``````8````&```$)@```CB0``J2\@`)Y-`0!#.2```$@```!@
M````8```0F```"J)`0!*.0``J2\@`)Y!+P")+^S_GD```"J)>%-#?0$`2CD`
M`*DOZ/^>0"``@$X``````````````````$)@`A!`/"`P0CBF`@A\^/_A^WD;
M?WSP_\'[$``!^-'_(?CP`()!``#?BP``OB_D`)Y!$=/_2Q@`0>C__V,X%!J_
M?$`HOW\P`)Q`KA@_?2\`B2\@`9Y`4"@_?:8#*7T0``!(```EB2\`B2\(`9Y`
M__^E./#_`$)`*+]_B`">0?__)3E`2+]_4"@_?:8#*7TP`=U!__^_+Q@`_D`D
M`0!(``!"8```)8DO`(DO#`">0/__I3CP_P!"4"B_?`(`)3D`$*DKD`"=00``
M`&!X^^1_L(+".P$`I3AX\\-_`!#`.)70_TL8`$'H,``A.'CSPW\0``'H\/_!
MZ_C_X>NF`PA\(`"`3B\`GB^D`)Y`````8```0F`"`&`X;=#_2Q@`0>AY&VE\
M,`""02X`0#EX2R-]``!)L3``(3@0``'H\/_!Z_C_X>NF`PA\(`"`3@```&``
M`$)@,``A.```8#@0``'H\/_!Z_C_X>NF`PA\(`"`3@``0F#__R4Y0$B_?U`H
M/WVF`RE]2`#=0?__OR\4`/Y`/```2```)8DO`(DOY/Z>0?__I3CP_P!"T/[_
M2_[_8CQX.6,X@=#_2Q@`0>AX__]+`0`@.:8#*7WH_O]+`0`@.:8#*7W,__]+
M``````````&``@```A!`/"`P0CBF`@A\X/^!^^C_H?O^_V(\\/_!^_C_X?N`
M.6,X_O_B/_[_(CTP."FA_O_"/!`XQNC^_^(\&#CGZ/[_`CT@.`CIL#G_._[_
MPC_^_T(]*#A*Z4@YWCO^_X(_T#F<._[_HC\0``'X0?\A^.`YO3OPCZWHF`"A
M^```H#AP`,'X>`#A^(```?F(`$'YD``AL?7N_TO^_V(\D#EC..GN_TO^_V(\
MF#EC.-WN_TO^_V(\J#EC.-'N_TMX^^-_R>[_2_[_8CS`.6,XO>[_2WCSPW^U
M[O]+>..#?ZWN_TMXZZ-_I>[_2_[_8CSP.6,XF>[_2_[_8CQ8.6,XC>[_2_[_
M8CP`.F,X@>[_2_[_8CP0.F,X=>[_2_[_8CQL`($X(#IC.`7M_TMY&V1\#`""
M07CKHW\E[_]+_O]B/&P`@3@X.F,XY>S_2WD;9'P0`()!_O]B/%`Z8S@![_]+
M_O]B/&P`@3A@.F,XP>S_2WD;9'Q0`()!>//#?^'N_TO^_X(\>/OC?Y@ZA#C1
M[O]+F``AZ?"/3>EY4BE]``!`.80`PD#``"$X$``!Z.#_@>OH_Z'K\/_!Z_C_
MX>NF`PA\(`"`3O[_8CQL`($X<#IC.%WL_TMY&V1\'`""07CC@W]][O]+G/__
M2P```&````!@``!"8/[_@CR!`&$XB#J$.`H`H#CQS/]+&`!!Z```HR]P_YY`
M>..#?XL`@3A![O]+8/__2\'-_TL8`$'H``````````&`!```````8````&``
M`$)@`A!`/"`P0CBF`@A\__]B//!_8X#__X,OM`=C?!```?B1_R'X\(]-Z6@`
M0?D``$`Y,`">06@`0>GPCRWI>4I*?0``(#ED`,)`<``A.!```>BF`PA\(`"`
M3@```&```$)@_O]B/&0`@3C0.6,X?>O_2P``(RPL`()!```CB0``8#@``*DO
M$`">03``(VG0`&-\X`]C>/__(CWP?VF0F/__2P``8#CP__]+^<S_2Q@`0>@`
M`````````8```````$)@`A!`/"`P0CBF`@A\$``!^.'_(?B]S?]+&`!!Z*7+
M_TL8`$'H```C+!@`@D$``&/H(``A.!```>BF`PA\(`"`3@``8#CL__]+````
M``````&`````````8````&```$)@`A!`/"`P0CBF`@A\_O\B/3@X*>GP_\'[
M_O^"/$`XA.CX_^'[R/\A^]#_0?O8_V'[X/^!^^C_H?MY2S]]_O^B/$@XI>C^
M_\(\4#C&Z/[_XCQ8..?H_O\"/6`X".D0``'X$?\A^/[_0CUH.$KI\(]MZ:@`
M8?D``&`Y<`#!.W``(?EX`('X@`"A^(@`P?B0`.'XF``!^:``0?F``()!_O]"
M/_[_8C]X&WQ\<#E:.V@Y>SLP``!(````8````&```$)@>..$?VW*_TL8`$'H
M``"C+Y``GD$)`/[K``"_+SP`GD%X^^-_;`"!..'I_TMY&WU\$`""00``78D`
M`(HOQ/^>0'C[XW]XXX1_\>O_2PD`_NL``+\OS/^>0*@`(>GPCTWI>5(I?0``
M0#F8`,)`\``A.!```>C(_R'KT/]!Z]C_8>O@_X'KZ/^AZ_#_P>OX_^'KI@,(
M?"``@$X```!@``!"8'CC@W^=S/]+&`!!Z'@;>7QXZZ-_C<S_2Q@`0>@4&GE\
M`@!C.+W*_TL8`$'H`0"`./__H#AXTT9_>..'?WC;:']XZZE_>!MY?`G+_TL8
M`$'H>/OC?WC+)']!Z_]+&/__2\'*_TL8`$'H``````````&`!P``````8```
M`&```$)@`A!`/"`P0CBF`@A\H/^!^M#_0?O^_X(^V/]A^^#_@?O^_X(_>!MZ
M?.C_H?OP_\'[2#F<._C_X?N8_V'Z>..#?ZC_H?JP_\'Z$``!^/__`#RX_^'Z
MX'T`8,#_`?O(_R'[_O_B/X@X_^O^_V(]F#AKZ?[_HCR@.*7H_O_"/*@XQNAJ
M`2%\_O_B/+`XY^B0.!3H_O\"/;@X".G^_T(]P#A*Z?[_(CW(."GI_O]B/W`X
M>^O^_Z(_>#B]Z_[_PC^`.-[K?`"!.`$`@3[PCPWKJ($4^P```#NP`.'[@`!A
M^X@`H?N0`,'[N``!^,``8?G(`*'XT`#!^-@`X?B8``'YH`!!^:@`(?GEY_]+
M>1M_?!``@D$``#^)``")+V@%GD"M_/]+D`#A.WP`H3MY&WY\I`*"07CSPW_M
MRO]+&`!!Z*0/8W@!`&,X'<G_2Q@`0>@``/Z(>!M[?```IR]``)Y!_O_B/G@;
M?WRH.O<Z````8```0F!X^^-_`0"`./__H#AXN^9^4<G_2Q@`0>@!`/Z,`@#_
M.P``IR_<_YY`L('A.\Q^OSL!?W_H``"C+Q0`GD!4``!("0!_Z```HR](`)Y!
M>.ND?RGG_TMY&WY\Z/^"00``/HD``(DOW/^>0<'O_TL``*,OT/^>07CSPW\I
MR?]+&`!!Z'D;?7R,`()`````8```0F"``*'K``"]+_@!GD$``#V)`0#`.P``
MB2]``)Y`Y`$`2```8#@D'_][L(%C8!0*8WP4^N-___^_/]!^O>L``+TOP`&>
M00``/8D!`-X[(`#>>P``B2^L`9Y!>.NC?[0'WW\Y[_]+``"C+[C_GD%XZZ-_
MH<C_2Q@`0>AY&WU\I/^"07CKHW_^_P(_F<G_2Q@`0>AX.1@[>!M_?'C;8W^%
MR?]+&`!!Z!3Z8WP$!.,[M`?_?WC[XW^MQ_]+&`!!Z/[_PCS^_R(]`0"`./__
MH#BP.L8X>.NG?WC#"'_`.BDY>-MJ?W@;>7SMQ_]+&`!!Z'C+(W_``8`X#<G_
M2Q@`0>C__X,O$`&>00```&`X@,+K``!^@%'(_TL8`$'H>,LD?Y@!HS@!`&`X
M?<;_2Q@`0>@``*,O,`&>00```&!(@"+I``#:Z/[_HCP!`(`X4#NE.'C+)W\`
M`&GH'<G_2Q@`0>@``&`X`0"!/JB!%.OPCXWJ>:(8?P``@#KT",)````AZ!``
M`>B8_V'JH/^!ZJC_H>JP_\'JN/_AZL#_`>O(_R'KT/]!Z]C_8>O@_X'KZ/^A
MZZ8#"'SP_\'K^/_AZR``@$X``$)@4<?_2Q@`0>AY&WY\9/V"0`D`?^@``*,O
MO`*>07CKI'\)Y?]+>1MI?.C_@D$``"F)``")+]S_GD'(__]+``!"8```H#M\
M_O]+````8```0F`QQ?]+&`!!Z````X$1`(@OM`<(?>#^GD$```!@2(`BZ0``
MVNC^_Z(\`0"`.,@ZI3AXRR=_``!IZ"G(_TL8`$'H``!@.`S__TL```!@``!"
M8```?H#]QO]+&`!!Z+`!(X$F!"E5`$")*[S^GD```'Z`X<;_2Q@`0>BT`:.#
M!<?_2Q@`0>@`Z(-_G/Z>0```?H#!QO]+&`!!Z+`!(X'^!2E5P`&)*X#^GD!X
M^^-_I<7_2Q@`0>A\`($X>!M]?/[_8CS8/&,X%>3_2P``HR^$!YY!``#ZZRW&
M_TL8`$'H>!MD?'C[XW_U\/]+>1M^?&0'PD%X\\-_'<?_2Q@`0>BT!W]\`P"?
M+TP`G4#\_W\X_O^"/!0:?GP(.X0X><?_2Q@`0>@``*,O+`">0`0`GR\`!IY!
M_/\_.;0'*7T42CY]__\IB2\`B2_H!9Y!````8```0F"I]_]+``"C+QP`GD!X
M\\-_``"`.$W%_TL8`$'H>1MV?"0!@D#^_X(\_O]B/)@ZA#C0.6,XA>7_2_[_
MPC_^_V(_6#S>.P``X#M)Q?]+&`!!Z/[_PCP!`(`X__^@."@[QCAX&VE\>,LG
M?WCKHW]XPPA_>//*?S@[>SOYQ/]+&`!!Z&```$@```!@````8```0F!1P_]+
M&`!!Z```(X$1`(DO6`">0.W$_TL8`$'H8`#!^P$`_SL!`(`XM`?_?___H#AX
M&VE\>-MF?WCKHW]XRR=_>,,(?WC[ZG^9Q/]+&`!!Z'CKHW_``8`XN<7_2Q@`
M0>C__X,OG/^>07C+(W]EP_]+&`!!Z'CKI']XXX-_K>3_2WCKHW^U]_]+>.NC
M?^3\_TNI]_]+>/OC?XG$_TL8`$'HT/S_2_[_PC\-`&`XH#K>.Z3Z_TON_X`X
M`@"@.#7#_TL8`$'H>+/#?J@!@3@&`*`XP</_2Q@`0>BH`2&)``")+Q``GD"I
M`2&)0P")+_0$GD$``*`X>+/#?@``@#@8`:$Z\<+_2Q@`0>C-[P`]NIA`/=+#
M(#U%9Z`\B:L(8?[<2F$R$,`\\.$I80``X#@!(Z5@(``(>2``2GEV5,9@(``I
M>>``H?@(`>'XZ``!^?``0?G@`$$[^`#!^``!(?D0`>'X6`'AD````&````!@
M``!"8```H#AXL\-^J`&!.`"`I6`1P_]+&`!!Z+0'>WP``)LOL`&=0`@!0>DD
M'VE[%%(I?2``*7E`2*I_F`.=01`!X>A8`4&!0A]H>P@!(?D40@=]M0=#?1`!
M`?EH`X)!0`!*(7C;?W\`4)M_"`"=0'A37WT4&GI\M`?W?S@`8SBH`8$X>+OE
M?LW#_TL8`$'H6`$A@13Z*7U``(DO6`$AD63_GD!0V']_J`%!.7C30W^T!WM_
M%+KJ?B7*_TL```!@``!"8#\`FR_,`)U`>-M^?WB[_WX``)^"&`"?@1P`'X`@
M`'^!P/_>.WC30W\D`)^`*`"_@"P`_X`P`!^!0`#_._3_WX#X_U^!_/\_@1@!
M@9+$_Y^",`&!D30!`9`X`6&1/`&!D!P!@9+(_Y^"0`&AD$0!X9!(`0&13`'!
MD"`!@9+,_Y^"4`%!D50!(9$D`8&2T/^?@B@!@9+4_Y^"+`&!DGW)_TL_`)XO
MM`?>?VC_G4'`_WL[OM%J5R``27DR,$I5`0`I.5#8:G]D-BEYM`=[?Q1*]WYX
MVV5_>+OD?D@`P#AXJZ-^8</_2Q@`0>@``*`X>+/#?E@!89.H`8$X`("E8&7!
M_TL8`$'HM`=[?```FR]8_IU!>+/#?@W!_TL8`$'H"`'AZ["!X3AA?\?KHN[J
M>P$`*CFT!TA].`")+Q1"!WV`_^`XM`<I?0@`Z)@<`IU!-P"J(+"!03D42FI\
M``"`.&A_8SBT!Z5\'<+_2Q@`0>@"1L5[`H3&>U,!P9M7`>&;`L+'>P)&Z'L"
MA.I[`L+I>U`!H9A1`<&8X`!A.%(!X9A4`0&950%!F58!(9EQR/]+\``!Z>``
MH>CH`,'H^`!!Z0`!(>D"1A=Y`L(;>6,!H9AG`<&8`D9>>0*$7WEK`0&9;P%!
MF2)&IW@"A+-X:`'AFFH!89L"PK1X`D;,>&P!P9MM`>&;`H35>`+"UGA@`>&8
M80%AF@*$&GD"PD!Y8@&!FF0!@9D"1BMY`H0C>64!H9IF`<&:`L(D>?[_XCYI
M`4&;;@$!F'`!89EQ`6&8>`'A.V`!P3MR`8&8<P$AF7,!83NH.O<Z%```2```
M`&````!@``!"8`$`_HQX^^-_`0"`./__H#AXN^9^+<#_2Q@`0>A`V+Y_`@#_
M.]S_GD```&`Y_O_"//[_0CW__Z`X&#O&.'C+)W^@`6&9>,,(?W@!(3E8/$HY
M`0"`.'CKHW_IO_]+&`!!Z'C+(W_-OO]+&`!!Z'CKI']XXX-_%>#_2WCKHW\=
M\_]+>.NC?TSX_TL```!@``!"8*@!X3K\_/]+````8```0F`0`0'I`0#H.&C\
M_TL(`/KK``"_+QSZGD%X^^-_U<#_2Q@`0>@#`*,K"/J=0/S_8SC^_X(\%!I_
M?!`[A#@UP?]+&`!!Z```HR_H^9Y`>/O^?^#Y_TO@`($X/P"J(!1*9'RT!Z5\
M``"`.#@`8S@%P/]+&`!!Z.``83B1QO]+``!`.1@!0?D@`4'Y*`%!^3`!0?DX
M`4'Y0`%!^4@!0?G`_?]+J@$AB4$`B2\(^YY`JP$AB4,`B2_\^IY`K`$AB4@`
MB2_P^IY`K0$AB44`B2_D^IY`>+/#?@(`H#C&_X`XU;W_2Q@`0>BH`8$X>+/#
M?BD`H#AAOO]+&`!!Z/[_PCS^_T(]>.NC?P$`@#C__Z`X&#O&.'C+)W]XPPA_
MJ`$A.5@\2CF!OO]+&`!!Z`#Z_TL``$)@``#:ZYSX_TLYOO]+&`!!Z```````
M```!@`T`````0F`"$$`\(#!".*8""'SH_Z'[P/\!^\C_(?O0_T'[V/]A^^#_
M@?OP_\'[^/_A^P```&`X@*+K$``!^%'_(?@``'V`\(\MZ6@`(?D``"`YE;[_
M2Q@`0>@!`"`Y9`"!.*D`(YG^_V(\L#EC.`'<_TL``",L$`""00``(XDQ`(DO
MM`*>0<GM_TL``'V`6;[_2Q@`0>C^_X(\`0"@.*@[A#@+`,`X(;__2Q@`0>@`
M`",LQ`*"00```&"PDB*!$`!#Z0$`B2\H`$KKK`*=0````&`@`"`_``#`.P$`
MX#NH@F([``0Y8T@``$@```!@````8```0F`0`(CH>,,#?RF__TL8`$'H``"C
M+Z0`GD`($#N!`0#_.P$`WCNT!]Y_`/B)?[0'_W^T!RE]C`"=0```?8"UO?]+
M&`!!Z'C31']X\\5_``#`.`&__TL8`$'H>1M\?#0"@D$``!SI$!#[Z"0?ZGL,
M`"B!*E`'?SA(*7\`!(DKA/^>00``?8!MO?]+&`!!Z```G.@``*`X`@#`.(F[
M_TL8`$'H>!MD?'C#`W^)OO]+&`!!Z```HR]D_YY!````8+*2(NG__TDY`/"*
M?]P!GD$``'V`(;W_2Q@`0>C^_X(\`0"@.+`[A#@#`,`XZ;W_2Q@`0>AY&W]\
M/`""00``?8#UO/]+&`!!Z!``/^G^_Z(\N#NE.```B>A=OO]+&`!!Z!``/^D`
M`"GI#``I@>-7*'G,`H)```!]@+V\_TL8`$'H_O^"/`$`H#C`.X0X`P#`.(6]
M_TL8`$'H>1M^?#P`@D'^_V(\9`"!.%@Y8S@1VO]+>1M_?```?8`,`H)!>;S_
M2Q@`0>@0`#[I>/OE?P``B>CEO?]+&`!!Z```?8!9O/]+&`!!Z```0#ED`($X
M>!MI?/[_8CQ(.6,XJ0!)F<'9_TL```!@``"C+W@;?WS`DF+X%`&>0<`!@#B]
MO/]+&`!!Z!$`@R]X&V9\$`">00$`(SD!`(DK0`+=06@`0>GPCPWI>4)*?0``
M`#DD`L)`L``A.!```>C`_P'KR/\AZ]#_0>O8_V'KX/^!Z^C_H>OP_\'K^/_A
MZZ8#"'P@`(!.````8```0F`!`".)``")+TC]GD```'V`H;O_2Q@`0>C^_X(\
M`0"@.*@[A#@+`,`X:;S_2Q@`0>@``",L3/V"0````&```$)@````8*B"8CM$
M_O]+``!"8````&"RDB+I__]).0#PBG\L_IY``0")+R3^G4`!`.`[``!]@#V[
M_TL8`$'H>--$?T&[_TL8`$'H"!`[@0$`7SFT!U]]`%")?]C_G4'P_?]+````
M8+B28NBQ[_]+````8```HR_`DF+X(`&>01``/ND@```]``0(80``2>D,`"J!
M.$@)?0`$B2NX`)Y`$`!JZ````&"XDN+K>/OD?X6X_TL8`$'H$``^Z2```#T`
M`/_K``0(87@;?'P``$GI#``J@3A("7T`!(DK3`">0!``JNC^_V(\>/OD?_`[
M8SAXXX9_,;G_2Q@`0>@```!@``!"8'&Z_TL8`$'H$`!>Z0```&"XDB+I``!J
MZ```B>A]X?]+]/W_2P``?8!)NO]+&`!!Z!``/ND``*`X`@#`.```B>AAN/]+
M&`!!Z'@;97R4__]+``!]@!VZ_TL8`$'H$``^Z0``H#@"`,`X``")Z#6X_TL8
M`$'H+/__2P``?8#UN?]+&`!!Z!``/^D``(GH%;G_2Q@`0>@<_?]+_O]B/,@[
M8SB!N/]+&`!!Z`FY_TL8`$'H$!`[Z?[_8CQX^^5_&#QC.```B>A=N/]+&`!!
MZ``````````!@`@``````&```$)@`A!`/"`P0CBF`@A\\/_!^_C_X?MX&WY\
M$``!^)'_(?CYYO]+```CB7@;?WP``*DO/`">00$`0SD8``!(``!"8```*HD!
M`$HY``"I+R``GD$O`(DO[/^>0```*HEX4U]]`0!*.0``J2_H_YY`S>K_2P``
MHR\T`)Y!``"^+RP`GD$``#Z)``")+R``GD'^_X(\>/OC?\`ZA#CIMO]+&`!!
MZ``8OW\<`)Y!<``A.!```>CP_\'K^/_AZZ8#"'P@`(!.<``A.'CSPW\0``'H
M\/_!Z_C_X>NF`PA\<-O_2P`````````!@`(``````&```$)@`A!`/"`P0CBF
M`@A\^/_A^P```&`X@.+K$``!^-'_(?@``'^`?;C_2Q@`0>C__X`X8;G_2Q@`
M0>@``'^`9;C_2Q@`0>C^_X(\``"@.,`1A#AAMO]+&`!!Z#``(3@0``'H^/_A
MZZ8#"'P@`(!.``````````&``0``````8````&`"$$`\(#!".*8""'S__R(]
MZ'\I.0``J2\0``'XX?\A^"0`WD'__R(]Z'_)Z/6U_TL8`$'H(``A.!```>BF
M`PA\(`"`3@``P#CD__]+``````````&`````````8````&`"$$`\(#!".*8"
M"'S0_T'[V/]A^^#_@?OH_Z'[\/_!^_C_X?O__\(___^B/XA]WCL0``'XD'V]
M.['_(?A0Z+Y_>!MZ?'@CFWQX*[Q\^/_>.P``X#O5M/]+````8'4>O7]``()!
M````8````&```$)@"0`^Z7C30W]XVV1_>..%?Z8#*7T8`$'X>$LL?0$`_SLA
M!(!.&`!!Z$#HOW_4_YY`4``A.!```>C0_T'KV/]AZ^#_@>NF`PA\Z/^AZ_#_
MP>OX_^'K(`"`3@`````````!@`8``````&````!@``!"8"``@$X`````````
M````````2@$``````*8""'P%`)]"I@)H??#_2^BF`PA\4&"+?11:8GW0_PPX
M``"+Z8+P`'BF`XE]"`!KZ2`$@$X```!@R/__2\3__TO`__]+O/__2[C__TNT
M__]+L/__2ZS__TNH__]+I/__2Z#__TN<__]+F/__2Y3__TN0__]+C/__2XC_
M_TN$__]+@/__2WS__TMX__]+=/__2W#__TML__]+:/__2V3__TM@__]+7/__
M2UC__TM4__]+4/__2TS__TM(__]+1/__2T#__TL\__]+./__2S3__TLP__]+
M+/__2RC__TLD__]+(/__2QS__TL8__]+%/__2Q#__TL,__]+"/__2P3__TL`
M__]+_/[_2_C^_TOT_O]+\/[_2^S^_TOH_O]+Y/[_2^#^_TO<_O]+V/[_2]3^
M_TO0_O]+S/[_2\C^_TO$_O]+P/[_2[S^_TL"$$`\(#!".*8""'P0``'XH?\A
M^&``(3@0``'HI@,(?"``@$X`````````````````'P`0`````)!E`!``````
M<&8`$``````!``(``````'!E<FQX<VDN8P````````!?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@(```````````V&P`$`````#H;``0`````/!L
M`!``````^&P`$```````;0`0`````!AM`!````````````````#0;``0````
M`&!I`!````````````````!P:@`0`````+!L`!``````N&P`$`````#`;``0
M`````,AL`!````````````````"8;``0`````*!L`!``````````````````
M``!>`````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````+W!R
M;V,O)6DO)7,``````&5X90``````+@````````!005)?5$5-4```````````
M4$%27U!23T=.04U%`````#H`````````)7,E<R5S```O`````````%!%4DPU
M3$E"``````````!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.````````
M`%!!4E]$14)51P````````!005)?0T%#2$4`````````4$%27T%21T,`````
M`````%!!4E]!4D=67S````````!005)?1TQ/0D%,7T1%0E5'``````````!0
M05)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````%!!4E]#3$5!3CT`
M```````Q`````````%-94U1%30``)3`R>``````E<R5S)7,E<P``````````
M<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*````````<&%R;``````N<&%R`````"5S
M)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E
M<P``````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F
M92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI
M"@```````$%21U8`````&`````````!P97)L`````#``````````56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!E>&5C=71I
M;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```````````E<P```````"UE````````+2T```````!54T52`````%53
M15).04U%``````````!435!$25(``%1%35!$25(`5$5-4`````!435``````
M`"]T;7``````3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4D%265]0051(
M`````$193$1?3$E"4D%265]0051(`````````%-(3$E"7U!!5$@```````!E
M=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@
M,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P
M87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%
M3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T
M96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI
M.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@
M.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H
M+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`]
M(&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@
M/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]
M/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO
M<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R
M7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF
M:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M
M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*
M;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@
M)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D
M(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D
M=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A
M;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=6
M7S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6
M>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD
M,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6
M*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T
M7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D
M<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIS965K
M(%]&2"P@+3@L(#(["G)E860@7T9(+"`D8G5F+"`X.PIL87-T('5N;&5S<R`D
M8G5F(&5Q(")<;E!!4BYP;5QN(CL*<V5E:R!?1D@L("TQ,BP@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`H)&]U="P@)&9I
M;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*:68@*"1O=70I('L*
M8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PIC
M:&UO9"`P-S4U+"`D9FEL96YA;64["GT*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE
M)&5X="(["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PIO<&5N(&UY("1O
M=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN;6]D92@D;W5T*3L*
M<')I;G0@)&]U="`D8G5F.PIC;&]S92`D;W5T.PI]"F5L<V4@>PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@
M/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K
M97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S
M<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T
M=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U
M;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB
M=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^
M>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T
M("1F:6QE;F%M92T^>V)U9GT["F-L;W-E("1O=70["GT*;W!E;B!M>2`D9F@L
M("<\)RP@)&YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D
M9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@
M)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*
M96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@
M9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]
M"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R
M(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E
M9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X[
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V
M86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@
M)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U
M8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N
M("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@
M)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE
M9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U
M;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D[
M"FUY($!I;F,@/2!S;W)T('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0I]
M(&=R97`@>PHA+T)31%!!3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY
M("5F:6QE<SL*+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK
M*R!F;W(@:V5Y<R`E.CH["B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,[
M"FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E
M=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA
M;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M
M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\[
M"FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM
M(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]
M("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E
M;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@
M+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@
M(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN
M+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I
M;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,
M12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@
M87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R
M:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA
M;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X
M(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN
M97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S
M=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T
M>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H
M95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE
M*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?
M;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T
M:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^
M8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@
M)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U
M<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S
M*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH
M6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?
M;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%2
M1U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D
M=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=
M(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T
M:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z
M.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A
M=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H
M*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D
M=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I
M<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,[
M"G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0IS
M=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@
M)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1?
M?2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL
M"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA
M;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L
M<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]
M('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J
M(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.
M5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I
M*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D
M9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F
M:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X
M(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN
M97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S
M=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T
M>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@
M>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*
M8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D[
M"GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F
M:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R
M8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P
M87)?=&5M<"\D8W)C)&5X="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL
M:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L
M("1F:6QE;F%M93L*?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE
M*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA
M;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE
M;F%M92D["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O
M9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA
M;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1
M)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!
M4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A
M97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.
M5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<
M4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L
M;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B
M0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E
M(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*,3L*7U]%3D1?7PH``````!0``````````7I2``1X00$;#`$`````
M`!0````<````L''__P`$`````````````!0````T````.''__Q``````````
M`````!0```!,````"+W__T@!````00E!#$0&00``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````"@(P`0
M`````%`C`!`````````````````!``````````$``````````0`````````%
M`@````````$`````````$`(````````!`````````!H"`````````0``````
M``!I`@````````$`````````M@,````````,`````````+`:`!``````#0``
M``````#09P`0`````!D`````````J*T!$``````;``````````@`````````
M&@````````"PK0$0`````!P`````````"`````````#U_O]O`````%@"`!``
M````!0`````````H#0`0``````8`````````.`,`$``````*`````````!4%
M````````"P`````````8`````````!4````````````````````#````````
M`)"P`1```````@````````!@!@```````!0`````````!P`````````7````
M`````#`4`!``````````<`````"@9@`0``````,``'`````````````````'
M`````````%@3`!``````"`````````#8``````````D`````````&```````
M``#^__]O`````!@3`!``````____;P`````"`````````/#__V\`````/A(`
M$```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_____P`````H;0`0`````"`P
M`A````````````````#X9P`0````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'0T,Z("A$96)I86X@-"XY+C(M,3`I(#0N
M.2XR`$=#0SH@*$1E8FEA;B`T+C@N-"TQ*2`T+C@N-```+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH
M87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N
M7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D
M871A`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD
M>6YA;6EC`"YD871A`"YG;W0`+F)S<P`N8V]M;65N=```````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````+`````0````(```````````(`$```````
M`@```````!$````````````````````!````````````````````$P````<`
M```"`````````!0"`!``````%`(````````@````````````````````!```
M`````````````````"$````'`````@`````````T`@`0`````#0"````````
M)`````````````````````0````````````````````T````]O__;P(`````
M````6`(`$`````!8`@```````.``````````!0`````````(````````````
M````````/@````L````"`````````#@#`!``````.`,```````#P"0``````
M``8````!````"``````````8`````````$8````#`````@`````````H#0`0
M`````"@-````````%04```````````````````$```````````````````!.
M````____;P(`````````/A(`$``````^$@```````-0`````````!0``````
M```"``````````(`````````6P```/[__V\"`````````!@3`!``````&!,`
M``````!```````````8````"````"````````````````````&H````$````
M`@````````!8$P`0`````%@3````````V``````````%``````````@`````
M````&`````````!T````!````$(`````````,!0`$``````P%````````&`&
M````````!0```!8````(`````````!@`````````?@````$````&````````
M`*`:`!``````H!H```````!,````````````````````(```````````````
M`````(0````!````!@``````````&P`0```````;````````T$P`````````
M`````````"````````````````````"*`````0````8`````````T&<`$```
M``#09P```````"0````````````````````$````````````````````D```
M``$````"`````````/AG`!``````^&<````````X00``````````````````
M"````````````````````)@````!`````@`````````PJ0`0`````#"I````
M````9`````````````````````0```````````````````"B````#@````,`
M````````J*T!$`````"HK0````````@````````````````````(````````
M````````````K@````\````#`````````+"M`1``````L*T````````(````
M````````````````"````````````````````+H````!`````P````````"X
MK0$0`````+BM````````"`````````````````````@`````````````````
M``"_````!@````,`````````P*T!$`````#`K0```````$`"````````!@``
M```````(`````````!``````````R`````$````#``````````"P`1``````
M`+`````````@````````````````````"````````````````````,X````!
M`````P`````````@L`$0`````""P````````<`````````````````````@`
M````````"`````````!Y````"`````,`````````D+`!$`````"0L```````
M`#`"```````````````````(``````````@`````````TP````@````#````
M`````,"R`1``````D+`````````P$```````````````````"```````````
M`````````-@````!````,````````````````````)"P````````.0``````
M``````````````$``````````0`````````!`````P``````````````````
M``````#)L````````.$````````````````````!````````````````````
